==> zio-aws-elasticloadbalancingv2_3-5.17.130.1-sources.jar: zio/aws/elasticloadbalancingv2/model/ModifyTargetGroupAttributesResponse.scala <==
package zio.aws.elasticloadbalancingv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ModifyTargetGroupAttributesResponse(
    attributes: Option[
      Iterable[zio.aws.elasticloadbalancingv2.model.TargetGroupAttribute]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse = {
    import ModifyTargetGroupAttributesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse
      .builder()
      .optionallyWith(
        attributes.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.attributes)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse.ReadOnly =
    zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse
      .wrap(buildAwsValue())
}
object ModifyTargetGroupAttributesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse =
      zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse(
        attributes.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def attributes: Option[
      List[zio.aws.elasticloadbalancingv2.model.TargetGroupAttribute.ReadOnly]
    ]
    def getAttributes: ZIO[Any, AwsError, List[
      zio.aws.elasticloadbalancingv2.model.TargetGroupAttribute.ReadOnly
    ]] = AwsError.unwrapOptionField("attributes", attributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse
  ) extends zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse.ReadOnly {
    override val attributes: Option[
      List[zio.aws.elasticloadbalancingv2.model.TargetGroupAttribute.ReadOnly]
    ] = scala
      .Option(impl.attributes())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticloadbalancingv2.model.TargetGroupAttribute.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse
  ): zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elasticloadbalancingv2_3-5.19.12.1-sources.jar: zio/aws/elasticloadbalancingv2/model/ModifyTargetGroupAttributesResponse.scala <==
package zio.aws.elasticloadbalancingv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ModifyTargetGroupAttributesResponse(
    attributes: Optional[
      Iterable[zio.aws.elasticloadbalancingv2.model.TargetGroupAttribute]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse = {
    import ModifyTargetGroupAttributesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse
      .builder()
      .optionallyWith(
        attributes.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.attributes)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse.ReadOnly =
    zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse
      .wrap(buildAwsValue())
}
object ModifyTargetGroupAttributesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse =
      zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse(
        attributes.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def attributes: Optional[
      List[zio.aws.elasticloadbalancingv2.model.TargetGroupAttribute.ReadOnly]
    ]
    def getAttributes: ZIO[Any, AwsError, List[
      zio.aws.elasticloadbalancingv2.model.TargetGroupAttribute.ReadOnly
    ]] = AwsError.unwrapOptionField("attributes", attributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse
  ) extends zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse.ReadOnly {
    override val attributes: Optional[
      List[zio.aws.elasticloadbalancingv2.model.TargetGroupAttribute.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.attributes())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticloadbalancingv2.model.TargetGroupAttribute.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse
  ): zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupAttributesResponse.ReadOnly =
    new Wrapper(impl)
}
